# Introduction

**Earnix is a global provider of Intelligent Insurance and Banking Operations through agile, composable and real-time solutions.**

This is a Software Development Kit for interactions with the Earnix Elevate line of products, providing HTTP clients and models covering 100% of the backend's capabilities, wrapped in an easy-to-use package. As of now, we only offer 1:1 interactions with the backend APIs, but we plan to introduce custom flows that call multiple APIs in the future.

With this package, you don't need to be learning the APIs, implementing the HTTP protocol or managing JSONs. For the best experience, we recommend using it with a modern Python LSP/IDE. We try to use type hinting whenever possible. The full developer experience includes automatic OOP model hierarchies, code completion, field validations and more.

## Requirements

- Python >= 3.9.
- An Earnix Elevate account.
- Valid `client_id` and `secret_key`, linked to that account or to a user within that account.
